summaryrefslogtreecommitdiffstats
path: root/style
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:13:46 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:13:46 -0600
commit53eb297cadc6d314fe1050c79f6b982bff24f248 (patch)
tree894b5e184f8ef2f62673ec2ac3faff94ad235e06 /style
parentac1e5178c2f5ebac0fb2194480bbb23a51103e32 (diff)
downloadtde-style-qtcurve-53eb297cadc6d314fe1050c79f6b982bff24f248.tar.gz
tde-style-qtcurve-53eb297cadc6d314fe1050c79f6b982bff24f248.zip
Rename a number of libraries and executables to avoid conflicts with KDE4
Diffstat (limited to 'style')
-rw-r--r--style/qtcurve.cpp12
-rw-r--r--style/qtcurve.h2
2 files changed, 7 insertions, 7 deletions
diff --git a/style/qtcurve.h b/style/qtcurve.h
index d4588bb..f9a5b95 100644
--- a/style/qtcurve.h
+++ b/style/qtcurve.h
@@ -250,7 +250,7 @@ class QtCurveStyle : public BASE_STYLE
void updateProgressPos();
void progressBarDestroyed(TQObject *bar);
void sliderThumbMoved(int val);
- void khtmlWidgetDestroyed(TQObject *o);
+ void tdehtmlWidgetDestroyed(TQObject *o);
void hoverWidgetDestroyed(TQObject *o);
private:
diff --git a/style/qtcurve.cpp b/style/qtcurve.cpp
index 19e7e34..e636293 100644
--- a/style/qtcurve.cpp
+++ b/style/qtcurve.cpp
@@ -440,7 +440,7 @@ static bool kickerIsTrans()
static bool isKhtmlWidget(const TQWidget *w, int level=1)
{
- return w && ((w->name() && 0==strcmp(w->name(), "__khtml")) ||
+ return w && ((w->name() && 0==strcmp(w->name(), "__tdehtml")) ||
(level && isKhtmlWidget(w->parentWidget(), --level)));
}
@@ -1476,7 +1476,7 @@ void QtCurveStyle::polish(const TQStyleControlElementData &ceData, ControlElemen
if(::isKhtmlFormWidget(widget))
{
itsKhtmlWidgets[widget]=true;
- connect(widget, TQT_SIGNAL(destroyed(TQObject *)), this, TQT_SLOT(khtmlWidgetDestroyed(TQObject *)));
+ connect(widget, TQT_SIGNAL(destroyed(TQObject *)), this, TQT_SLOT(tdehtmlWidgetDestroyed(TQObject *)));
}
if(enableFilter && isSpecialHover(widget))
@@ -4365,9 +4365,9 @@ void QtCurveStyle::drawPrimitive(TQ_PrimitiveElement pe, TQPainter *p, const TQS
// HACK!! (From Plastik)
//
// In this place there is no reliable way to detect if we are in khtml; the
// only thing we know is that khtml buffers its widgets into a pixmap. So
// when the paint device is a TQPixmap, chances are high that we are in khtml.
// It's possible that this breaks other things, so let's see how it works...
if (p->device() && dynamic_cast<TQPixmap*>(p->device()))
itsFormMode=true;
@@ -8751,7 +8751,7 @@ void QtCurveStyle::sliderThumbMoved(int)
slider->update();
}
-void QtCurveStyle::khtmlWidgetDestroyed(TQObject *o)
+void QtCurveStyle::tdehtmlWidgetDestroyed(TQObject *o)
{
itsKhtmlWidgets.remove(TQT_TQWIDGET_CONST(o));
}
@@ -4365,9 +4365,9 @@ void QtCurveStyle::drawPrimitive(TQ_PrimitiveElement pe, TQPainter *p, const TQS
// HACK!! (From Plastik)
//
- // In this place there is no reliable way to detect if we are in khtml; the
- // only thing we know is that khtml buffers its widgets into a pixmap. So
- // when the paint device is a TQPixmap, chances are high that we are in khtml.
+ // In this place there is no reliable way to detect if we are in tdehtml; the
+ // only thing we know is that tdehtml buffers its widgets into a pixmap. So
+ // when the paint device is a TQPixmap, chances are high that we are in tdehtml.
// It's possible that this breaks other things, so let's see how it works...
if (p->device() && dynamic_cast<TQPixmap*>(p->device()))